#[repr(u8)]pub enum ResponseCode {
NoError = 0,
FormatError = 1,
ServerFailure = 2,
NameError = 3,
NotImplemented = 4,
Refused = 5,
}Expand description
Variants
NoError = 0
No Error.
No error condition.
FormatError = 1
Format Error.
The name server was unable to interpret the query.
ServerFailure = 2
Server Failure.
The name server was unable to process this query due to a problem with the name server.
NameError = 3
Name Error.
Meaningful only for responses from an authoritative name server, this code signifies that the domain name referenced in the query does not exist.
NotImplemented = 4
Not Implemented
The name server does not support the requested kind of query.
Refused = 5
Refused.
The name server refuses to perform the specified operation for policy reasons. For example, a name server may not wish to provide the information to the particular requester, or a name server may not wish to perform a particular operation (e.g., zone transfer) for particular data.